Class: Aws::DirectoryService::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::DirectoryService::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-directoryservice/client.rb,
sig/client.rbs
Overview
An API client for DirectoryService. To construct a client, you need to configure a :region and :credentials.
client = Aws::DirectoryService::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the developer guide.
See #initialize for a full list of supported configuration options.
Defined Under Namespace
Modules: _AcceptSharedDirectoryResponseSuccess, _AddIpRoutesResponseSuccess, _AddRegionResponseSuccess, _AddTagsToResourceResponseSuccess, _CancelSchemaExtensionResponseSuccess, _ConnectDirectoryResponseSuccess, _CreateAliasResponseSuccess, _CreateComputerResponseSuccess, _CreateConditionalForwarderResponseSuccess, _CreateDirectoryResponseSuccess, _CreateHybridADResponseSuccess, _CreateLogSubscriptionResponseSuccess, _CreateMicrosoftADResponseSuccess, _CreateSnapshotResponseSuccess, _CreateTrustResponseSuccess, _DeleteADAssessmentResponseSuccess, _DeleteConditionalForwarderResponseSuccess, _DeleteDirectoryResponseSuccess, _DeleteLogSubscriptionResponseSuccess, _DeleteSnapshotResponseSuccess, _DeleteTrustResponseSuccess, _DeregisterCertificateResponseSuccess, _DeregisterEventTopicResponseSuccess, _DescribeADAssessmentResponseSuccess, _DescribeCAEnrollmentPolicyResponseSuccess, _DescribeCertificateResponseSuccess, _DescribeClientAuthenticationSettingsResponseSuccess, _DescribeConditionalForwardersResponseSuccess, _DescribeDirectoriesResponseSuccess, _DescribeDirectoryDataAccessResponseSuccess, _DescribeDomainControllersResponseSuccess, _DescribeEventTopicsResponseSuccess, _DescribeHybridADUpdateResponseSuccess, _DescribeLDAPSSettingsResponseSuccess, _DescribeRegionsResponseSuccess, _DescribeSettingsResponseSuccess, _DescribeSharedDirectoriesResponseSuccess, _DescribeSnapshotsResponseSuccess, _DescribeTrustsResponseSuccess, _DescribeUpdateDirectoryResponseSuccess, _DisableCAEnrollmentPolicyResponseSuccess, _DisableClientAuthenticationResponseSuccess, _DisableDirectoryDataAccessResponseSuccess, _DisableLDAPSResponseSuccess, _DisableRadiusResponseSuccess, _DisableSsoResponseSuccess, _EnableCAEnrollmentPolicyResponseSuccess, _EnableClientAuthenticationResponseSuccess, _EnableDirectoryDataAccessResponseSuccess, _EnableLDAPSResponseSuccess, _EnableRadiusResponseSuccess, _EnableSsoResponseSuccess, _GetDirectoryLimitsResponseSuccess, _GetSnapshotLimitsResponseSuccess, _ListADAssessmentsResponseSuccess, _ListCertificatesResponseSuccess, _ListIpRoutesResponseSuccess, _ListLogSubscriptionsResponseSuccess, _ListSchemaExtensionsResponseSuccess, _ListTagsForResourceResponseSuccess, _RegisterCertificateResponseSuccess, _RegisterEventTopicResponseSuccess, _RejectSharedDirectoryResponseSuccess, _RemoveIpRoutesResponseSuccess, _RemoveRegionResponseSuccess, _RemoveTagsFromResourceResponseSuccess, _ResetUserPasswordResponseSuccess, _RestoreFromSnapshotResponseSuccess, _ShareDirectoryResponseSuccess, _StartADAssessmentResponseSuccess, _StartSchemaExtensionResponseSuccess, _UnshareDirectoryResponseSuccess, _UpdateConditionalForwarderResponseSuccess, _UpdateDirectorySetupResponseSuccess, _UpdateHybridADResponseSuccess, _UpdateNumberOfDomainControllersResponseSuccess, _UpdateRadiusResponseSuccess, _UpdateSettingsResponseSuccess, _UpdateTrustResponseSuccess, _VerifyTrustResponseSuccess
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#accept_shared_directory(params = {}) ⇒ Types::AcceptSharedDirectoryResult
Accepts a directory sharing request that was sent from the directory owner account.
-
#add_ip_routes(params = {}) ⇒ Struct
If the DNS server for your self-managed domain uses a publicly addressable IP address, you must add a CIDR address block to correctly route traffic to and from your Microsoft AD on Amazon Web Services.
-
#add_region(params = {}) ⇒ Struct
Adds two domain controllers in the specified Region for the specified directory.
-
#add_tags_to_resource(params = {}) ⇒ Struct
Adds or overwrites one or more tags for the specified directory.
-
#cancel_schema_extension(params = {}) ⇒ Struct
Cancels an in-progress schema extension to a Microsoft AD directory.
-
#connect_directory(params = {}) ⇒ Types::ConnectDirectoryResult
Creates an AD Connector to connect to a self-managed directory.
-
#create_alias(params = {}) ⇒ Types::CreateAliasResult
Creates an alias for a directory and assigns the alias to the directory.
-
#create_computer(params = {}) ⇒ Types::CreateComputerResult
Creates an Active Directory computer object in the specified directory.
-
#create_conditional_forwarder(params = {}) ⇒ Struct
Creates a conditional forwarder associated with your Amazon Web Services directory.
-
#create_directory(params = {}) ⇒ Types::CreateDirectoryResult
Creates a Simple AD directory.
-
#create_hybrid_ad(params = {}) ⇒ Types::CreateHybridADResult
Creates a hybrid directory that connects your self-managed Active Directory (AD) infrastructure and Amazon Web Services.
-
#create_log_subscription(params = {}) ⇒ Struct
Creates a subscription to forward real-time Directory Service domain controller security logs to the specified Amazon CloudWatch log group in your Amazon Web Services account.
-
#create_microsoft_ad(params = {}) ⇒ Types::CreateMicrosoftADResult
Creates a Microsoft AD directory in the Amazon Web Services Cloud.
-
#create_snapshot(params = {}) ⇒ Types::CreateSnapshotResult
Creates a snapshot of a Simple AD or Microsoft AD directory in the Amazon Web Services cloud.
-
#create_trust(params = {}) ⇒ Types::CreateTrustResult
Directory Service for Microsoft Active Directory allows you to configure trust relationships.
-
#delete_ad_assessment(params = {}) ⇒ Types::DeleteADAssessmentResult
Deletes a directory assessment and all associated data.
-
#delete_conditional_forwarder(params = {}) ⇒ Struct
Deletes a conditional forwarder that has been set up for your Amazon Web Services directory.
-
#delete_directory(params = {}) ⇒ Types::DeleteDirectoryResult
Deletes an Directory Service directory.
-
#delete_log_subscription(params = {}) ⇒ Struct
Deletes the specified log subscription.
-
#delete_snapshot(params = {}) ⇒ Types::DeleteSnapshotResult
Deletes a directory snapshot.
-
#delete_trust(params = {}) ⇒ Types::DeleteTrustResult
Deletes an existing trust relationship between your Managed Microsoft AD directory and an external domain.
-
#deregister_certificate(params = {}) ⇒ Struct
Deletes from the system the certificate that was registered for secure LDAP or client certificate authentication.
-
#deregister_event_topic(params = {}) ⇒ Struct
Removes the specified directory as a publisher to the specified Amazon SNS topic.
-
#describe_ad_assessment(params = {}) ⇒ Types::DescribeADAssessmentResult
Retrieves detailed information about a directory assessment, including its current status, validation results, and configuration details.
-
#describe_ca_enrollment_policy(params = {}) ⇒ Types::DescribeCAEnrollmentPolicyResult
Retrieves detailed information about the certificate authority (CA) enrollment policy for the specified directory.
-
#describe_certificate(params = {}) ⇒ Types::DescribeCertificateResult
Displays information about the certificate registered for secure LDAP or client certificate authentication.
-
#describe_client_authentication_settings(params = {}) ⇒ Types::DescribeClientAuthenticationSettingsResult
Retrieves information about the type of client authentication for the specified directory, if the type is specified.
-
#describe_conditional_forwarders(params = {}) ⇒ Types::DescribeConditionalForwardersResult
Obtains information about the conditional forwarders for this account.
-
#describe_directories(params = {}) ⇒ Types::DescribeDirectoriesResult
Obtains information about the directories that belong to this account.
-
#describe_directory_data_access(params = {}) ⇒ Types::DescribeDirectoryDataAccessResult
Obtains status of directory data access enablement through the Directory Service Data API for the specified directory.
-
#describe_domain_controllers(params = {}) ⇒ Types::DescribeDomainControllersResult
Provides information about any domain controllers in your directory.
-
#describe_event_topics(params = {}) ⇒ Types::DescribeEventTopicsResult
Obtains information about which Amazon SNS topics receive status messages from the specified directory.
-
#describe_hybrid_ad_update(params = {}) ⇒ Types::DescribeHybridADUpdateResult
Retrieves information about update activities for a hybrid directory.
-
#describe_ldaps_settings(params = {}) ⇒ Types::DescribeLDAPSSettingsResult
Describes the status of LDAP security for the specified directory.
-
#describe_regions(params = {}) ⇒ Types::DescribeRegionsResult
Provides information about the Regions that are configured for multi-Region replication.
-
#describe_settings(params = {}) ⇒ Types::DescribeSettingsResult
Retrieves information about the configurable settings for the specified directory.
-
#describe_shared_directories(params = {}) ⇒ Types::DescribeSharedDirectoriesResult
Returns the shared directories in your account.
-
#describe_snapshots(params = {}) ⇒ Types::DescribeSnapshotsResult
Obtains information about the directory snapshots that belong to this account.
-
#describe_trusts(params = {}) ⇒ Types::DescribeTrustsResult
Obtains information about the trust relationships for this account.
-
#describe_update_directory(params = {}) ⇒ Types::DescribeUpdateDirectoryResult
Describes the updates of a directory for a particular update type.
-
#disable_ca_enrollment_policy(params = {}) ⇒ Struct
Disables the certificate authority (CA) enrollment policy for the specified directory.
-
#disable_client_authentication(params = {}) ⇒ Struct
Disables alternative client authentication methods for the specified directory.
-
#disable_directory_data_access(params = {}) ⇒ Struct
Deactivates access to directory data via the Directory Service Data API for the specified directory.
-
#disable_ldaps(params = {}) ⇒ Struct
Deactivates LDAP secure calls for the specified directory.
-
#disable_radius(params = {}) ⇒ Struct
Disables multi-factor authentication (MFA) with the Remote Authentication Dial In User Service (RADIUS) server for an AD Connector or Microsoft AD directory.
-
#disable_sso(params = {}) ⇒ Struct
Disables single-sign on for a directory.
-
#enable_ca_enrollment_policy(params = {}) ⇒ Struct
Enables certificate authority (CA) enrollment policy for the specified directory.
-
#enable_client_authentication(params = {}) ⇒ Struct
Enables alternative client authentication methods for the specified directory.
-
#enable_directory_data_access(params = {}) ⇒ Struct
Enables access to directory data via the Directory Service Data API for the specified directory.
-
#enable_ldaps(params = {}) ⇒ Struct
Activates the switch for the specific directory to always use LDAP secure calls.
-
#enable_radius(params = {}) ⇒ Struct
Enables multi-factor authentication (MFA) with the Remote Authentication Dial In User Service (RADIUS) server for an AD Connector or Microsoft AD directory.
-
#enable_sso(params = {}) ⇒ Struct
Enables single sign-on for a directory.
-
#get_directory_limits(params = {}) ⇒ Types::GetDirectoryLimitsResult
Obtains directory limit information for the current Region.
-
#get_snapshot_limits(params = {}) ⇒ Types::GetSnapshotLimitsResult
Obtains the manual snapshot limits for a directory.
-
#list_ad_assessments(params = {}) ⇒ Types::ListADAssessmentsResult
Retrieves a list of directory assessments for the specified directory or all assessments in your account.
-
#list_certificates(params = {}) ⇒ Types::ListCertificatesResult
For the specified directory, lists all the certificates registered for a secure LDAP or client certificate authentication.
-
#list_ip_routes(params = {}) ⇒ Types::ListIpRoutesResult
Lists the address blocks that you have added to a directory.
-
#list_log_subscriptions(params = {}) ⇒ Types::ListLogSubscriptionsResult
Lists the active log subscriptions for the Amazon Web Services account.
-
#list_schema_extensions(params = {}) ⇒ Types::ListSchemaExtensionsResult
Lists all schema extensions applied to a Microsoft AD Directory.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResult
Lists all tags on a directory.
-
#register_certificate(params = {}) ⇒ Types::RegisterCertificateResult
Registers a certificate for a secure LDAP or client certificate authentication.
-
#register_event_topic(params = {}) ⇒ Struct
Associates a directory with an Amazon SNS topic.
-
#reject_shared_directory(params = {}) ⇒ Types::RejectSharedDirectoryResult
Rejects a directory sharing request that was sent from the directory owner account.
-
#remove_ip_routes(params = {}) ⇒ Struct
Removes IP address blocks from a directory.
-
#remove_region(params = {}) ⇒ Struct
Stops all replication and removes the domain controllers from the specified Region.
-
#remove_tags_from_resource(params = {}) ⇒ Struct
Removes tags from a directory.
-
#reset_user_password(params = {}) ⇒ Struct
Resets the password for any user in your Managed Microsoft AD or Simple AD directory.
-
#restore_from_snapshot(params = {}) ⇒ Struct
Restores a directory using an existing directory snapshot.
-
#share_directory(params = {}) ⇒ Types::ShareDirectoryResult
Shares a specified directory (
DirectoryId) in your Amazon Web Services account (directory owner) with another Amazon Web Services account (directory consumer). -
#start_ad_assessment(params = {}) ⇒ Types::StartADAssessmentResult
Initiates a directory assessment to validate your self-managed AD environment for hybrid domain join.
-
#start_schema_extension(params = {}) ⇒ Types::StartSchemaExtensionResult
Applies a schema extension to a Microsoft AD directory.
-
#unshare_directory(params = {}) ⇒ Types::UnshareDirectoryResult
Stops the directory sharing between the directory owner and consumer accounts.
-
#update_conditional_forwarder(params = {}) ⇒ Struct
Updates a conditional forwarder that has been set up for your Amazon Web Services directory.
-
#update_directory_setup(params = {}) ⇒ Struct
Updates directory configuration for the specified update type.
-
#update_hybrid_ad(params = {}) ⇒ Types::UpdateHybridADResult
Updates the configuration of an existing hybrid directory.
-
#update_number_of_domain_controllers(params = {}) ⇒ Struct
Adds or removes domain controllers to or from the directory.
-
#update_radius(params = {}) ⇒ Struct
Updates the Remote Authentication Dial In User Service (RADIUS) server information for an AD Connector or Microsoft AD directory.
-
#update_settings(params = {}) ⇒ Types::UpdateSettingsResult
Updates the configurable settings for the specified directory.
-
#update_trust(params = {}) ⇒ Types::UpdateTrustResult
Updates the trust that has been set up between your Managed Microsoft AD directory and an self-managed Active Directory.
-
#verify_trust(params = {}) ⇒ Types::VerifyTrustResult
Directory Service for Microsoft Active Directory allows you to configure and verify trust relationships.
Class Method Summary collapse
- .errors_module ⇒ Object private
- .new ⇒ Object
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
-
#wait_until(waiter_name, params = {}, options = {}) {|w.waiter| ... } ⇒ Boolean
Polls an API operation until a resource enters a desired state.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
478 479 480 |
# File 'lib/aws-sdk-directoryservice/client.rb', line 478 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
5074 5075 5076 |
# File 'lib/aws-sdk-directoryservice/client.rb', line 5074 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
5077 5078 5079 |
# File 'lib/aws-sdk-directoryservice/client.rb', line 5077 def errors_module Errors end |
.new ⇒ Object
14 |
# File 'sig/client.rbs', line 14
def self.new: (
|
Instance Method Details
#accept_shared_directory(params = {}) ⇒ Types::AcceptSharedDirectoryResult
Accepts a directory sharing request that was sent from the directory owner account.
87 |
# File 'sig/client.rbs', line 87
def accept_shared_directory: (
|
#add_ip_routes(params = {}) ⇒ Struct
If the DNS server for your self-managed domain uses a publicly addressable IP address, you must add a CIDR address block to correctly route traffic to and from your Microsoft AD on Amazon Web Services. AddIpRoutes adds this address block. You can also use AddIpRoutes to facilitate routing traffic that uses public IP ranges from your Microsoft AD on Amazon Web Services to a peer VPC.
Before you call AddIpRoutes, ensure that all of the required permissions have been explicitly granted through a policy. For details about what permissions are required to run the AddIpRoutes operation, see Directory Service API Permissions: Actions, Resources, and Conditions Reference.
96 |
# File 'sig/client.rbs', line 96
def add_ip_routes: (
|
#add_region(params = {}) ⇒ Struct
Adds two domain controllers in the specified Region for the specified directory.
113 |
# File 'sig/client.rbs', line 113
def add_region: (
|
#add_tags_to_resource(params = {}) ⇒ Struct
Adds or overwrites one or more tags for the specified directory. Each directory can have a maximum of 50 tags. Each tag consists of a key and optional value. Tag keys must be unique to each resource.
127 |
# File 'sig/client.rbs', line 127
def add_tags_to_resource: (
|
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
4934 4935 4936 4937 4938 4939 4940 4941 4942 4943 4944 4945 4946 4947 4948 4949 4950 |
# File 'lib/aws-sdk-directoryservice/client.rb', line 4934 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::DirectoryService') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-directoryservice' context[:gem_version] = '1.106.0' Seahorse::Client::Request.new(handlers, context) end |
#cancel_schema_extension(params = {}) ⇒ Struct
Cancels an in-progress schema extension to a Microsoft AD directory.
Once a schema extension has started replicating to all domain
controllers, the task can no longer be canceled. A schema extension
can be canceled during any of the following states; Initializing,
CreatingSnapshot, and UpdatingSchema.
142 |
# File 'sig/client.rbs', line 142
def cancel_schema_extension: (
|
#connect_directory(params = {}) ⇒ Types::ConnectDirectoryResult
Creates an AD Connector to connect to a self-managed directory.
Before you call ConnectDirectory, ensure that all of the required
permissions have been explicitly granted through a policy. For details
about what permissions are required to run the ConnectDirectory
operation, see Directory Service API Permissions: Actions, Resources,
and Conditions Reference.
153 |
# File 'sig/client.rbs', line 153
def connect_directory: (
|
#create_alias(params = {}) ⇒ Types::CreateAliasResult
Creates an alias for a directory and assigns the alias to the
directory. The alias is used to construct the access URL for the
directory, such as http://<alias>.awsapps.com.
After an alias has been created, it cannot be deleted or reused, so this operation should only be used when absolutely necessary.
182 |
# File 'sig/client.rbs', line 182
def create_alias: (
|
#create_computer(params = {}) ⇒ Types::CreateComputerResult
Creates an Active Directory computer object in the specified directory.
193 |
# File 'sig/client.rbs', line 193
def create_computer: (
|
#create_conditional_forwarder(params = {}) ⇒ Struct
Creates a conditional forwarder associated with your Amazon Web Services directory. Conditional forwarders are required in order to set up a trust relationship with another domain. The conditional forwarder points to the trusted domain.
211 |
# File 'sig/client.rbs', line 211
def create_conditional_forwarder: (
|
#create_directory(params = {}) ⇒ Types::CreateDirectoryResult
Creates a Simple AD directory. For more information, see Simple Active Directory in the Directory Service Admin Guide.
Before you call CreateDirectory, ensure that all of the required
permissions have been explicitly granted through a policy. For details
about what permissions are required to run the CreateDirectory
operation, see Directory Service API Permissions: Actions, Resources,
and Conditions Reference.
224 |
# File 'sig/client.rbs', line 224
def create_directory: (
|
#create_hybrid_ad(params = {}) ⇒ Types::CreateHybridADResult
Creates a hybrid directory that connects your self-managed Active Directory (AD) infrastructure and Amazon Web Services.
You must have a successful directory assessment using StartADAssessment to validate your environment compatibility before you use this operation.
Updates are applied asynchronously. Use DescribeDirectories to monitor the progress of directory creation.
249 |
# File 'sig/client.rbs', line 249
def create_hybrid_ad: (
|
#create_log_subscription(params = {}) ⇒ Struct
Creates a subscription to forward real-time Directory Service domain controller security logs to the specified Amazon CloudWatch log group in your Amazon Web Services account.
265 |
# File 'sig/client.rbs', line 265
def create_log_subscription: (
|
#create_microsoft_ad(params = {}) ⇒ Types::CreateMicrosoftADResult
Creates a Microsoft AD directory in the Amazon Web Services Cloud. For more information, see Managed Microsoft AD in the Directory Service Admin Guide.
Before you call CreateMicrosoftAD, ensure that all of the required permissions have been explicitly granted through a policy. For details about what permissions are required to run the CreateMicrosoftAD operation, see Directory Service API Permissions: Actions, Resources, and Conditions Reference.
276 |
# File 'sig/client.rbs', line 276
def create_microsoft_ad: (
|
#create_snapshot(params = {}) ⇒ Types::CreateSnapshotResult
Creates a snapshot of a Simple AD or Microsoft AD directory in the Amazon Web Services cloud.
301 |
# File 'sig/client.rbs', line 301
def create_snapshot: (
|
#create_trust(params = {}) ⇒ Types::CreateTrustResult
Directory Service for Microsoft Active Directory allows you to configure trust relationships. For example, you can establish a trust between your Managed Microsoft AD directory, and your existing self-managed Microsoft Active Directory. This would allow you to provide users and groups access to resources in either domain, with a single set of credentials.
This action initiates the creation of the Amazon Web Services side of a trust relationship between an Managed Microsoft AD directory and an external domain. You can create either a forest trust or an external trust.
312 |
# File 'sig/client.rbs', line 312
def create_trust: (
|
#delete_ad_assessment(params = {}) ⇒ Types::DeleteADAssessmentResult
Deletes a directory assessment and all associated data. This operation permanently removes the assessment results, validation reports, and configuration information.
You cannot delete system-initiated assessments. You can delete customer-created assessments even if they are in progress.
329 |
# File 'sig/client.rbs', line 329
def delete_ad_assessment: (
|
#delete_conditional_forwarder(params = {}) ⇒ Struct
Deletes a conditional forwarder that has been set up for your Amazon Web Services directory.
338 |
# File 'sig/client.rbs', line 338
def delete_conditional_forwarder: (
|
#delete_directory(params = {}) ⇒ Types::DeleteDirectoryResult
Deletes an Directory Service directory.
Before you call DeleteDirectory, ensure that all of the required
permissions have been explicitly granted through a policy. For details
about what permissions are required to run the DeleteDirectory
operation, see Directory Service API Permissions: Actions, Resources,
and Conditions Reference.
349 |
# File 'sig/client.rbs', line 349
def delete_directory: (
|
#delete_log_subscription(params = {}) ⇒ Struct
Deletes the specified log subscription.
358 |
# File 'sig/client.rbs', line 358
def delete_log_subscription: (
|
#delete_snapshot(params = {}) ⇒ Types::DeleteSnapshotResult
Deletes a directory snapshot.
368 |
# File 'sig/client.rbs', line 368
def delete_snapshot: (
|
#delete_trust(params = {}) ⇒ Types::DeleteTrustResult
Deletes an existing trust relationship between your Managed Microsoft AD directory and an external domain.
378 |
# File 'sig/client.rbs', line 378
def delete_trust: (
|
#deregister_certificate(params = {}) ⇒ Struct
Deletes from the system the certificate that was registered for secure LDAP or client certificate authentication.
388 |
# File 'sig/client.rbs', line 388
def deregister_certificate: (
|
#deregister_event_topic(params = {}) ⇒ Struct
Removes the specified directory as a publisher to the specified Amazon SNS topic.
398 |
# File 'sig/client.rbs', line 398
def deregister_event_topic: (
|
#describe_ad_assessment(params = {}) ⇒ Types::DescribeADAssessmentResult
Retrieves detailed information about a directory assessment, including its current status, validation results, and configuration details. Use this operation to monitor assessment progress and review results.
410 |
# File 'sig/client.rbs', line 410
def describe_ad_assessment: (
|
#describe_ca_enrollment_policy(params = {}) ⇒ Types::DescribeCAEnrollmentPolicyResult
Retrieves detailed information about the certificate authority (CA) enrollment policy for the specified directory. This policy determines how client certificates are automatically enrolled and managed through Amazon Web Services Private Certificate Authority.
424 |
# File 'sig/client.rbs', line 424
def describe_ca_enrollment_policy: (
|
#describe_certificate(params = {}) ⇒ Types::DescribeCertificateResult
Displays information about the certificate registered for secure LDAP or client certificate authentication.
434 |
# File 'sig/client.rbs', line 434
def describe_certificate: (
|
#describe_client_authentication_settings(params = {}) ⇒ Types::DescribeClientAuthenticationSettingsResult
Retrieves information about the type of client authentication for the
specified directory, if the type is specified. If no type is
specified, information about all client authentication types that are
supported for the specified directory is retrieved. Currently, only
SmartCard is supported.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
446 |
# File 'sig/client.rbs', line 446
def describe_client_authentication_settings: (
|
#describe_conditional_forwarders(params = {}) ⇒ Types::DescribeConditionalForwardersResult
Obtains information about the conditional forwarders for this account.
If no input parameters are provided for RemoteDomainNames, this request describes all conditional forwarders for the specified directory ID.
459 |
# File 'sig/client.rbs', line 459
def describe_conditional_forwarders: (
|
#describe_directories(params = {}) ⇒ Types::DescribeDirectoriesResult
Obtains information about the directories that belong to this account.
You can retrieve information about specific directories by passing the
directory identifiers in the DirectoryIds parameter. Otherwise, all
directories that belong to the current account are returned.
This operation supports pagination with the use of the NextToken
request and response parameters. If more results are available, the
DescribeDirectoriesResult.NextToken member contains a token that you
pass in the next call to DescribeDirectories to retrieve the next set
of items.
You can also specify a maximum number of return results with the
Limit parameter.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
471 |
# File 'sig/client.rbs', line 471
def describe_directories: (
|
#describe_directory_data_access(params = {}) ⇒ Types::DescribeDirectoryDataAccessResult
Obtains status of directory data access enablement through the Directory Service Data API for the specified directory.
483 |
# File 'sig/client.rbs', line 483
def describe_directory_data_access: (
|
#describe_domain_controllers(params = {}) ⇒ Types::DescribeDomainControllersResult
Provides information about any domain controllers in your directory.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
494 |
# File 'sig/client.rbs', line 494
def describe_domain_controllers: (
|
#describe_event_topics(params = {}) ⇒ Types::DescribeEventTopicsResult
Obtains information about which Amazon SNS topics receive status messages from the specified directory.
If no input parameters are provided, such as DirectoryId or TopicName, this request describes all of the associations in the account.
507 |
# File 'sig/client.rbs', line 507
def describe_event_topics: (
|
#describe_hybrid_ad_update(params = {}) ⇒ Types::DescribeHybridADUpdateResult
Retrieves information about update activities for a hybrid directory. This operation provides details about configuration changes, administrator account updates, and self-managed instance settings (IDs and DNS IPs).
The following waiters are defined for this operation (see #wait_until for detailed usage):
* hybrid_ad_updated
519 |
# File 'sig/client.rbs', line 519
def describe_hybrid_ad_update: (
|
#describe_ldaps_settings(params = {}) ⇒ Types::DescribeLDAPSSettingsResult
Describes the status of LDAP security for the specified directory.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
532 |
# File 'sig/client.rbs', line 532
def describe_ldaps_settings: (
|
#describe_regions(params = {}) ⇒ Types::DescribeRegionsResult
Provides information about the Regions that are configured for multi-Region replication.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
546 |
# File 'sig/client.rbs', line 546
def describe_regions: (
|
#describe_settings(params = {}) ⇒ Types::DescribeSettingsResult
Retrieves information about the configurable settings for the specified directory.
560 |
# File 'sig/client.rbs', line 560
def describe_settings: (
|
#describe_shared_directories(params = {}) ⇒ Types::DescribeSharedDirectoriesResult
Returns the shared directories in your account.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
573 |
# File 'sig/client.rbs', line 573
def describe_shared_directories: (
|
#describe_snapshots(params = {}) ⇒ Types::DescribeSnapshotsResult
Obtains information about the directory snapshots that belong to this account.
This operation supports pagination with the use of the NextToken request and response parameters. If more results are available, the DescribeSnapshots.NextToken member contains a token that you pass in the next call to DescribeSnapshots to retrieve the next set of items.
You can also specify a maximum number of return results with the Limit parameter.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
587 |
# File 'sig/client.rbs', line 587
def describe_snapshots: (
|
#describe_trusts(params = {}) ⇒ Types::DescribeTrustsResult
Obtains information about the trust relationships for this account.
If no input parameters are provided, such as DirectoryId or TrustIds, this request describes all the trust relationships belonging to the account.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
601 |
# File 'sig/client.rbs', line 601
def describe_trusts: (
|
#describe_update_directory(params = {}) ⇒ Types::DescribeUpdateDirectoryResult
Describes the updates of a directory for a particular update type.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
615 |
# File 'sig/client.rbs', line 615
def describe_update_directory: (
|
#disable_ca_enrollment_policy(params = {}) ⇒ Struct
Disables the certificate authority (CA) enrollment policy for the specified directory. This stops automatic certificate enrollment and management for domain-joined clients, but does not affect existing certificates.
Disabling the CA enrollment policy prevents new certificates from being automatically enrolled, but existing certificates remain valid and functional until they expire.
627 |
# File 'sig/client.rbs', line 627
def disable_ca_enrollment_policy: (
|
#disable_client_authentication(params = {}) ⇒ Struct
Disables alternative client authentication methods for the specified directory.
636 |
# File 'sig/client.rbs', line 636
def disable_client_authentication: (
|
#disable_directory_data_access(params = {}) ⇒ Struct
Deactivates access to directory data via the Directory Service Data API for the specified directory. For more information, see Directory Service Data API Reference.
646 |
# File 'sig/client.rbs', line 646
def disable_directory_data_access: (
|
#disable_ldaps(params = {}) ⇒ Struct
Deactivates LDAP secure calls for the specified directory.
655 |
# File 'sig/client.rbs', line 655
def disable_ldaps: (
|
#disable_radius(params = {}) ⇒ Struct
Disables multi-factor authentication (MFA) with the Remote Authentication Dial In User Service (RADIUS) server for an AD Connector or Microsoft AD directory.
665 |
# File 'sig/client.rbs', line 665
def disable_radius: (
|
#disable_sso(params = {}) ⇒ Struct
Disables single-sign on for a directory.
674 |
# File 'sig/client.rbs', line 674
def disable_sso: (
|
#enable_ca_enrollment_policy(params = {}) ⇒ Struct
Enables certificate authority (CA) enrollment policy for the specified directory. This allows domain-joined clients to automatically request and receive certificates from the specified Amazon Web Services Private Certificate Authority.
685 |
# File 'sig/client.rbs', line 685
def enable_ca_enrollment_policy: (
|
#enable_client_authentication(params = {}) ⇒ Struct
Enables alternative client authentication methods for the specified directory.
695 |
# File 'sig/client.rbs', line 695
def enable_client_authentication: (
|
#enable_directory_data_access(params = {}) ⇒ Struct
Enables access to directory data via the Directory Service Data API for the specified directory. For more information, see Directory Service Data API Reference.
705 |
# File 'sig/client.rbs', line 705
def enable_directory_data_access: (
|
#enable_ldaps(params = {}) ⇒ Struct
Activates the switch for the specific directory to always use LDAP secure calls.
714 |
# File 'sig/client.rbs', line 714
def enable_ldaps: (
|
#enable_radius(params = {}) ⇒ Struct
Enables multi-factor authentication (MFA) with the Remote Authentication Dial In User Service (RADIUS) server for an AD Connector or Microsoft AD directory.
724 |
# File 'sig/client.rbs', line 724
def enable_radius: (
|
#enable_sso(params = {}) ⇒ Struct
Enables single sign-on for a directory. Single sign-on allows users in your directory to access certain Amazon Web Services services from a computer joined to the directory without having to enter their credentials separately.
734 |
# File 'sig/client.rbs', line 734
def enable_sso: (
|
#get_directory_limits(params = {}) ⇒ Types::GetDirectoryLimitsResult
Obtains directory limit information for the current Region.
746 |
# File 'sig/client.rbs', line 746
def get_directory_limits: (
|
#get_snapshot_limits(params = {}) ⇒ Types::GetSnapshotLimitsResult
Obtains the manual snapshot limits for a directory.
755 |
# File 'sig/client.rbs', line 755
def get_snapshot_limits: (
|
#list_ad_assessments(params = {}) ⇒ Types::ListADAssessmentsResult
Retrieves a list of directory assessments for the specified directory or all assessments in your account. Use this operation to monitor assessment status and manage multiple assessments.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
766 |
# File 'sig/client.rbs', line 766
def list_ad_assessments: (
|
#list_certificates(params = {}) ⇒ Types::ListCertificatesResult
For the specified directory, lists all the certificates registered for a secure LDAP or client certificate authentication.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
779 |
# File 'sig/client.rbs', line 779
def list_certificates: (
|
#list_ip_routes(params = {}) ⇒ Types::ListIpRoutesResult
Lists the address blocks that you have added to a directory.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
792 |
# File 'sig/client.rbs', line 792
def list_ip_routes: (
|
#list_log_subscriptions(params = {}) ⇒ Types::ListLogSubscriptionsResult
Lists the active log subscriptions for the Amazon Web Services account.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
805 |
# File 'sig/client.rbs', line 805
def list_log_subscriptions: (
|
#list_schema_extensions(params = {}) ⇒ Types::ListSchemaExtensionsResult
Lists all schema extensions applied to a Microsoft AD Directory.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
818 |
# File 'sig/client.rbs', line 818
def list_schema_extensions: (
|
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResult
Lists all tags on a directory.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
831 |
# File 'sig/client.rbs', line 831
def list_tags_for_resource: (
|
#register_certificate(params = {}) ⇒ Types::RegisterCertificateResult
Registers a certificate for a secure LDAP or client certificate authentication.
843 |
# File 'sig/client.rbs', line 843
def register_certificate: (
|
#register_event_topic(params = {}) ⇒ Struct
Associates a directory with an Amazon SNS topic. This establishes the directory as a publisher to the specified Amazon SNS topic. You can then receive email or text (SMS) messages when the status of your directory changes. You get notified if your directory goes from an Active status to an Impaired or Inoperable status. You also receive a notification when the directory returns to an Active status.
857 |
# File 'sig/client.rbs', line 857
def register_event_topic: (
|
#reject_shared_directory(params = {}) ⇒ Types::RejectSharedDirectoryResult
Rejects a directory sharing request that was sent from the directory owner account.
868 |
# File 'sig/client.rbs', line 868
def reject_shared_directory: (
|
#remove_ip_routes(params = {}) ⇒ Struct
Removes IP address blocks from a directory.
877 |
# File 'sig/client.rbs', line 877
def remove_ip_routes: (
|
#remove_region(params = {}) ⇒ Struct
Stops all replication and removes the domain controllers from the
specified Region. You cannot remove the primary Region with this
operation. Instead, use the DeleteDirectory API.
888 |
# File 'sig/client.rbs', line 888
def remove_region: (
|
#remove_tags_from_resource(params = {}) ⇒ Struct
Removes tags from a directory.
897 |
# File 'sig/client.rbs', line 897
def remove_tags_from_resource: (
|
#reset_user_password(params = {}) ⇒ Struct
Resets the password for any user in your Managed Microsoft AD or Simple AD directory. Disabled users will become enabled and can be authenticated following the API call.
You can reset the password for any user in your directory with the following exceptions:
-
For Simple AD, you cannot reset the password for any user that is a member of either the Domain Admins or Enterprise Admins group except for the administrator user.
-
For Managed Microsoft AD, you can only reset the password for a user that is in an OU based off of the NetBIOS name that you typed when you created your directory. For example, you cannot reset the password for a user in the Amazon Web Services Reserved OU. For more information about the OU structure for an Managed Microsoft AD directory, see What Gets Created in the Directory Service Administration Guide.
907 |
# File 'sig/client.rbs', line 907
def reset_user_password: (
|
#restore_from_snapshot(params = {}) ⇒ Struct
Restores a directory using an existing directory snapshot.
When you restore a directory from a snapshot, any changes made to the directory after the snapshot date are overwritten.
This action returns as soon as the restore operation is initiated. You
can monitor the progress of the restore operation by calling the
DescribeDirectories operation with the directory identifier. When the
DirectoryDescription.Stage value changes to Active, the restore
operation is complete.
918 |
# File 'sig/client.rbs', line 918
def restore_from_snapshot: (
|
#share_directory(params = {}) ⇒ Types::ShareDirectoryResult
Shares a specified directory (DirectoryId) in your Amazon Web
Services account (directory owner) with another Amazon Web Services
account (directory consumer). With this operation you can use your
directory from any Amazon Web Services account and from any Amazon VPC
within an Amazon Web Services Region.
When you share your Managed Microsoft AD directory, Directory Service creates a shared directory in the directory consumer account. This shared directory contains the metadata to provide access to the directory within the directory owner account. The shared directory is visible in all VPCs in the directory consumer account.
The ShareMethod parameter determines whether the specified directory
can be shared between Amazon Web Services accounts inside the same
Amazon Web Services organization (ORGANIZATIONS). It also determines
whether you can share the directory with any other Amazon Web Services
account either inside or outside of the organization (HANDSHAKE).
The ShareNotes parameter is only used when HANDSHAKE is called,
which sends a directory sharing request to the directory consumer.
928 |
# File 'sig/client.rbs', line 928
def share_directory: (
|
#start_ad_assessment(params = {}) ⇒ Types::StartADAssessmentResult
Initiates a directory assessment to validate your self-managed AD environment for hybrid domain join. The assessment checks compatibility and connectivity of the self-managed AD environment.
A directory assessment is automatically created when you create a
hybrid directory. There are two types of assessments: CUSTOMER and
SYSTEM. Your Amazon Web Services account has a limit of 100
CUSTOMER directory assessments.
The assessment process typically takes 30 minutes or more to complete.
The assessment process is asynchronous and you can monitor it with
DescribeADAssessment.
The InstanceIds must have a one-to-one correspondence with
CustomerDnsIps, meaning that if the IP address for instance
i-10243410 is 10.24.34.100 and the IP address for instance i-10243420
is 10.24.34.200, then the input arrays must maintain the same order
relationship, either [10.24.34.100, 10.24.34.200] paired with
[i-10243410, i-10243420] or [10.24.34.200, 10.24.34.100] paired
with [i-10243420, i-10243410].
Note: You must provide exactly one DirectoryId or
AssessmentConfiguration.
944 |
# File 'sig/client.rbs', line 944
def start_ad_assessment: (
|
#start_schema_extension(params = {}) ⇒ Types::StartSchemaExtensionResult
Applies a schema extension to a Microsoft AD directory.
964 |
# File 'sig/client.rbs', line 964
def start_schema_extension: (
|
#unshare_directory(params = {}) ⇒ Types::UnshareDirectoryResult
Stops the directory sharing between the directory owner and consumer accounts.
977 |
# File 'sig/client.rbs', line 977
def unshare_directory: (
|
#update_conditional_forwarder(params = {}) ⇒ Struct
Updates a conditional forwarder that has been set up for your Amazon Web Services directory.
990 |
# File 'sig/client.rbs', line 990
def update_conditional_forwarder: (
|
#update_directory_setup(params = {}) ⇒ Struct
Updates directory configuration for the specified update type.
1002 |
# File 'sig/client.rbs', line 1002
def update_directory_setup: (
|
#update_hybrid_ad(params = {}) ⇒ Types::UpdateHybridADResult
Updates the configuration of an existing hybrid directory. You can recover hybrid directory administrator account or modify self-managed instance settings.
Updates are applied asynchronously. Use DescribeHybridADUpdate to monitor the progress of configuration changes.
The InstanceIds must have a one-to-one correspondence with
CustomerDnsIps, meaning that if the IP address for instance
i-10243410 is 10.24.34.100 and the IP address for instance i-10243420
is 10.24.34.200, then the input arrays must maintain the same order
relationship, either [10.24.34.100, 10.24.34.200] paired with
[i-10243410, i-10243420] or [10.24.34.200, 10.24.34.100] paired
with [i-10243420, i-10243410].
1025 |
# File 'sig/client.rbs', line 1025
def update_hybrid_ad: (
|
#update_number_of_domain_controllers(params = {}) ⇒ Struct
Adds or removes domain controllers to or from the directory. Based on the difference between current value and new value (provided through this API call), domain controllers will be added or removed. It may take up to 45 minutes for any new domain controllers to become fully active once the requested number of domain controllers is updated. During this time, you cannot make another update request.
1041 |
# File 'sig/client.rbs', line 1041
def update_number_of_domain_controllers: (
|
#update_radius(params = {}) ⇒ Struct
Updates the Remote Authentication Dial In User Service (RADIUS) server information for an AD Connector or Microsoft AD directory.
1051 |
# File 'sig/client.rbs', line 1051
def update_radius: (
|
#update_settings(params = {}) ⇒ Types::UpdateSettingsResult
Updates the configurable settings for the specified directory.
1062 |
# File 'sig/client.rbs', line 1062
def update_settings: (
|
#update_trust(params = {}) ⇒ Types::UpdateTrustResult
Updates the trust that has been set up between your Managed Microsoft AD directory and an self-managed Active Directory.
1079 |
# File 'sig/client.rbs', line 1079
def update_trust: (
|
#verify_trust(params = {}) ⇒ Types::VerifyTrustResult
Directory Service for Microsoft Active Directory allows you to configure and verify trust relationships.
This action verifies a trust relationship between your Managed Microsoft AD directory and an external domain.
1090 |
# File 'sig/client.rbs', line 1090
def verify_trust: (
|
#wait_until(waiter_name, params = {}, options = {}) {|w.waiter| ... } ⇒ Boolean
Polls an API operation until a resource enters a desired state.
Basic Usage
A waiter will call an API operation until:
- It is successful
- It enters a terminal state
- It makes the maximum number of attempts
In between attempts, the waiter will sleep.
# polls in a loop, sleeping between attempts
client.wait_until(waiter_name, params)
Configuration
You can configure the maximum number of polling attempts, and the delay (in seconds) between each polling attempt. You can pass configuration as the final arguments hash.
# poll for ~25 seconds
client.wait_until(waiter_name, params, {
max_attempts: 5,
delay: 5,
})
Callbacks
You can be notified before each polling attempt and before each
delay. If you throw :success or :failure from these callbacks,
it will terminate the waiter.
started_at = Time.now
client.wait_until(waiter_name, params, {
# disable max attempts
max_attempts: nil,
# poll for 1 hour, instead of a number of attempts
before_wait: -> (attempts, response) do
throw :failure if Time.now - started_at > 3600
end
})
Handling Errors
When a waiter is unsuccessful, it will raise an error. All of the failure errors extend from Waiters::Errors::WaiterFailed.
begin
client.wait_until(...)
rescue Aws::Waiters::Errors::WaiterFailed
# resource did not enter the desired state in time
end
Valid Waiters
The following table lists the valid waiter names, the operations they call,
and the default :delay and :max_attempts values.
| waiter_name | params | :delay | :max_attempts |
|---|---|---|---|
| hybrid_ad_updated | #describe_hybrid_ad_update | 120 | 60 |
1096 |
# File 'sig/client.rbs', line 1096
def wait_until: (:hybrid_ad_updated waiter_name,
|
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
5048 5049 5050 |
# File 'lib/aws-sdk-directoryservice/client.rb', line 5048 def waiter_names waiters.keys end |