Class: Aws::DirectoryService::Types::ADAssessmentLimitExceededException
- Inherits:
-
Struct
- Object
- Struct
- Aws::DirectoryService::Types::ADAssessmentLimitExceededException
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-directoryservice/types.rb
Overview
A directory assessment is automatically created when you create a
hybrid directory. There are two types of assessments: CUSTOMER and
SYSTEM. Your Amazon Web Services account has a limit of 100
CUSTOMER directory assessments.
If you attempt to create a hybrid directory; and you already have 100
CUSTOMER directory assessments;, you will encounter an error. Delete
assessments to free up capacity before trying again.
You can request an increase to your CUSTOMER directory assessment
quota by contacting customer support or delete existing CUSTOMER
directory assessments; to free up capacity.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#message ⇒ String
The descriptive message for the exception.
-
#request_id ⇒ String
The Amazon Web Services request identifier.
Instance Attribute Details
#message ⇒ String
The descriptive message for the exception.
36 37 38 39 40 41 |
# File 'lib/aws-sdk-directoryservice/types.rb', line 36 class ADAssessmentLimitExceededException < Struct.new( :message, :request_id) SENSITIVE = [] include Aws::Structure end |
#request_id ⇒ String
The Amazon Web Services request identifier.
36 37 38 39 40 41 |
# File 'lib/aws-sdk-directoryservice/types.rb', line 36 class ADAssessmentLimitExceededException < Struct.new( :message, :request_id) SENSITIVE = [] include Aws::Structure end |