Class: Aws::DirectoryService::Types::DescribeClientAuthenticationSettingsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-directoryservice/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#directory_idString

The identifier of the directory for which to retrieve information.



1781
1782
1783
1784
1785
1786
1787
1788
# File 'lib/aws-sdk-directoryservice/types.rb', line 1781

class DescribeClientAuthenticationSettingsRequest < Struct.new(
  :directory_id,
  :type,
  :next_token,
  :limit)
  SENSITIVE = []
  include Aws::Structure
end

#limitInteger

The maximum number of items to return. If this value is zero, the maximum number of items is specified by the limitations of the operation.



1781
1782
1783
1784
1785
1786
1787
1788
# File 'lib/aws-sdk-directoryservice/types.rb', line 1781

class DescribeClientAuthenticationSettingsRequest < Struct.new(
  :directory_id,
  :type,
  :next_token,
  :limit)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The DescribeClientAuthenticationSettingsResult.NextToken value from a previous call to DescribeClientAuthenticationSettings. Pass null if this is the first call.



1781
1782
1783
1784
1785
1786
1787
1788
# File 'lib/aws-sdk-directoryservice/types.rb', line 1781

class DescribeClientAuthenticationSettingsRequest < Struct.new(
  :directory_id,
  :type,
  :next_token,
  :limit)
  SENSITIVE = []
  include Aws::Structure
end

#typeString

The type of client authentication for which to retrieve information. If no type is specified, a list of all client authentication types that are supported for the specified directory is retrieved.



1781
1782
1783
1784
1785
1786
1787
1788
# File 'lib/aws-sdk-directoryservice/types.rb', line 1781

class DescribeClientAuthenticationSettingsRequest < Struct.new(
  :directory_id,
  :type,
  :next_token,
  :limit)
  SENSITIVE = []
  include Aws::Structure
end