Class: Aws::DirectoryService::Types::DescribeSettingsResult

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-directoryservice/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#directory_idString

The identifier of the directory.

Returns:

  • (String)


2204
2205
2206
2207
2208
2209
2210
# File 'lib/aws-sdk-directoryservice/types.rb', line 2204

class DescribeSettingsResult < Struct.new(
  :directory_id,
  :setting_entries,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

If not null, token that indicates that more results are available. Pass this value for the NextToken parameter in a subsequent call to DescribeSettings to retrieve the next set of items.

Returns:

  • (String)


2204
2205
2206
2207
2208
2209
2210
# File 'lib/aws-sdk-directoryservice/types.rb', line 2204

class DescribeSettingsResult < Struct.new(
  :directory_id,
  :setting_entries,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#setting_entriesArray<Types::SettingEntry>

The list of SettingEntry objects that were retrieved.

It is possible that this list contains less than the number of items specified in the Limit member of the request. This occurs if there are less than the requested number of items left to retrieve, or if the limitations of the operation have been exceeded.

Returns:



2204
2205
2206
2207
2208
2209
2210
# File 'lib/aws-sdk-directoryservice/types.rb', line 2204

class DescribeSettingsResult < Struct.new(
  :directory_id,
  :setting_entries,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end