Class: Aws::DirectoryService::Waiters::HybridADUpdated

Inherits:
Object
  • Object
show all
Defined in:
sig/waiters.rbs,
lib/aws-sdk-directoryservice/waiters.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(options) ⇒ HybridADUpdated

Returns a new instance of HybridADUpdated.

Parameters:

  • options (Hash)

Options Hash (options):

  • :client (required, Client)
  • :max_attempts (Integer) — default: 60
  • :delay (Integer) — default: 120
  • :before_attempt (Proc)
  • :before_wait (Proc)


84
85
# File 'lib/aws-sdk-directoryservice/waiters.rb', line 84

def initialize: (?client: Client, ?max_attempts: Integer, ?delay: Integer, ?before_attempt: Proc, ?before_wait: Proc) -> void
| (?Hash[Symbol, untyped]) -> void

Instance Attribute Details

#waiterObject (readonly)

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.



116
117
118
# File 'lib/aws-sdk-directoryservice/waiters.rb', line 116

def waiter
  @waiter
end

Instance Method Details

#wait(params = {}) ⇒ Types::DescribeHybridADUpdateResult

Returns a response object which responds to the following methods:

Options Hash (params):

  • :directory_id (required, String)

    The identifier of the hybrid directory for which to retrieve update information.

  • :update_type (String)

    The type of update activities to retrieve. Valid values include SelfManagedInstances and HybridAdministratorAccount.

  • :next_token (String)

    The pagination token from a previous request to DescribeHybridADUpdate. Pass null if this is the first request.

Returns:



111
# File 'lib/aws-sdk-directoryservice/waiters.rb', line 111

def wait: (